==> tor-ctrl_5.0.orig.tar.xz: README_generic.md <==
# Tor controller command line tool #

Command line tool for setting up stream for communication from the
Tor Controller's (client) to a Tor process (server). The client send
commands using TCP sockets or Unix-domain sockets and receive replies
from the server.

https://gitweb.torproject.org/torspec.git/tree/control-spec.txt

This package is produced independently of, and carries no guarantee from,
The Tor Project.

## How to install `tor-ctrl` using apt-get ##

1\. Download the APT Signing Key.

```
wget https://www.kicksecure.com/derivative.asc
```

Users can [check the Signing Key](https://www.kicksecure.com/wiki/Signing_Key) for better security.

2\. Add the APT Signing Key..

```
sudo cp ~/derivative.asc /usr/share/keyrings/derivative.asc
```

3\. Add the derivative repository.

```
echo "deb [signed-by=/usr/share/keyrings/derivative.asc] https://deb.kicksecure.com bullseye main contrib non-free" | sudo tee /etc/apt/sources.list.d/derivative.list
```

4\. Update your package lists.

```
sudo apt-get update
```

5\. Install `tor-ctrl`.

```
sudo apt-get install tor-ctrl
```

## How to Build deb Package from Source Code ##

Can be build using standard Debian package build tools such as:

```
dpkg-buildpackage -b
```

See instructions.

NOTE: Replace `generic-package` with the actual name of this package `tor-ctrl`.

* **A)** [easy](https://www.kicksecure.com/wiki/Dev/Build_Documentation/generic-package/easy), _OR_
* **B)** [including verifying software signatures](https://www.kicksecure.com/wiki/Dev/Build_Documentation/generic-package)

## Contact ##

* [Free Forum Support](https://forums.kicksecure.com)
* [Professional Support](https://www.kicksecure.com/wiki/Professional_Support)

## Donate ##

`tor-ctrl` requires [donations](https://www.kicksecure.com/wiki/Donate) to stay alive!

==> tor-ctrl_5.3.orig.tar.xz: README_generic.md <==
# Tor controller command line tool #

Command line tool for setting up stream for communication from the
Tor Controller's (client) to a Tor process (server). The client send
commands using TCP sockets or Unix-domain sockets and receive replies
from the server.

https://gitweb.torproject.org/torspec.git/tree/control-spec.txt

This package is produced independently of, and carries no guarantee from,
The Tor Project.

## How to install `tor-ctrl` using apt-get ##

1\. Download the APT Signing Key.

```
wget https://www.kicksecure.com/keys/derivative.asc
```

Users can [check the Signing Key](https://www.kicksecure.com/wiki/Signing_Key) for better security.

2\. Add the APT Signing Key.

```
sudo cp ~/derivative.asc /usr/share/keyrings/derivative.asc
```

3\. Add the derivative repository.

```
echo "deb [signed-by=/usr/share/keyrings/derivative.asc] https://deb.kicksecure.com bookworm main contrib non-free" | sudo tee /etc/apt/sources.list.d/derivative.list
```

4\. Update your package lists.

```
sudo apt-get update
```

5\. Install `tor-ctrl`.

```
sudo apt-get install tor-ctrl
```

## How to Build deb Package from Source Code ##

Can be build using standard Debian package build tools such as:

```
dpkg-buildpackage -b
```

See instructions.

NOTE: Replace `generic-package` with the actual name of this package `tor-ctrl`.

* **A)** [easy](https://www.kicksecure.com/wiki/Dev/Build_Documentation/generic-package/easy), _OR_
* **B)** [including verifying software signatures](https://www.kicksecure.com/wiki/Dev/Build_Documentation/generic-package)

## Contact ##

* [Free Forum Support](https://forums.kicksecure.com)
* [Premium Support](https://www.kicksecure.com/wiki/Premium_Support)

## Donate ##

`tor-ctrl` requires [donations](https://www.kicksecure.com/wiki/Donate) to stay alive!
